Parally: Parallel Network Computing in Python — Parally documentation

# Parally: Parallel Network Computing in Python

# Description

Parally is a Python library for parallel network computing. It is designed to be simple to use and easy to extend. It is built on top of the standard Python library and uses the multiprocessing module for parallelism.

# Server

A simple server class that listens on a given host and port.

parally.Server.bind_parameters(self, parameters) → None

  bind_parameters Binds a list of parameters to the server.

  Parameters:

    parameters (list) – A list of parameters to be bound to the server.

parally.Server.on_completed(self, callback) → None

  on_completed Sets the callback function to be called when the server has completed all tasks.

  Parameters:

    callback (function) – The callback function to be called when the server has completed all tasks.

parally.Server.on_error(self, callback)

  on_error Sets the callback function to be called when the server has encountered an error.

  Parameters:

    callback (function) – The callback function to be called when the server has encountered an error.

parally.Server.start(self) → None

  start Starts the server.

parally.Server.stop(self) → list

  stop Stops the server.

  Returns:

    A list of results.

  Return type:

    list

# Client

A simple client class that connects to a given host and port.

parally.Client.close(self) → None

  close Closes the client.

parally.Client.run_function(self, function) → None

  input_function Sets the function to run on the server.

  Parameters:

    function (function) – The function to run on the server.

parally.Client.start(self) → None

  start Starts the client.